@@ -24,6 +24,13 @@ import azure.cognitiveservices.speech.audio
 logger = logging.getLogger(__name__)
 
 AUDIO_LOCALE_OVERRIDE_MAP = {
+    'sr-Latn-RS': 'sr_RS'
+}
+
+GENDER_MAP = {
+    'Female': cloudlanguagetools.constants.Gender.Female,
+    'Male': cloudlanguagetools.constants.Gender.Male,
+    'Neutral': cloudlanguagetools.constants.Gender.Any,
 }
 
 class AzureVoice(cloudlanguagetools.ttsvoice.TtsVoice):
@@ -39,7 +46,7 @@ class AzureVoice(cloudlanguagetools.ttsvoice.TtsVoice):
         self.display_name = voice_data['DisplayName']
         self.local_name = voice_data['LocalName']
         self.short_name = voice_data['ShortName']
-        self.gender = cloudlanguagetools.constants.Gender[voice_data['Gender']]
+        self.gender = GENDER_MAP[voice_data['Gender']]
 
         self.locale = locale
         self.voice_type = voice_data['VoiceType']
@@ -206,7 +213,7 @@ class AzureService(cloudlanguagetools.service.Service):
             cloudlanguagetools.options.AudioFormat.ogg_opus: 'Ogg48Khz16BitMonoOpus'
         }
 
-        output_temp_file = tempfile.NamedTemporaryFile()
+        output_temp_file = tempfile.NamedTemporaryFile(prefix=f'cloudlanguage_tools_{self.__class__.__name__}_audio', suffix=f'.{audio_format.name}')
         output_temp_filename = output_temp_file.name
         speech_config = azure.cognitiveservices.speech.SpeechConfig(subscription=self.key, region=self.region)
         speech_config.set_speech_synthesis_output_format(azure.cognitiveservices.speech.SpeechSynthesisOutputFormat[audio_format_map[audio_format]])
@@ -302,7 +309,7 @@ class AzureService(cloudlanguagetools.service.Service):
             try:
                 result.append(AzureTranslationLanguage(language_id))
             except KeyError:
-                logging.error(f'could not process translation language for {language_id}, {data}', exc_info=True)
+                logging.warning(f'could not process translation language for {language_id}, {data}', exc_info=True)
         return result
 
     def get_transliteration_language_list(self):
@@ -377,7 +384,7 @@ class AzureService(cloudlanguagetools.service.Service):
         return response[0]['text']
 
     # supported languages: https://docs.microsoft.com/en-us/azure/cognitive-services/speech-service/language-support#speech-to-text
-    def speech_to_text(self, mp3_filepath, language, audio_format):
+    def speech_to_text(self, mp3_filepath, audio_format, language=None):
         speech_config = azure.cognitiveservices.speech.SpeechConfig(subscription=self.key, region=self.region)
 
         if audio_format == cloudlanguagetools.options.AudioFormat.mp3:
@@ -390,7 +397,14 @@ class AzureService(cloudlanguagetools.service.Service):
         audio_input = azure.cognitiveservices.speech.audio.AudioConfig(filename=wav_filepath)
 
         # Creates a recognizer with the given settings
-        speech_recognizer = azure.cognitiveservices.speech.SpeechRecognizer(speech_config=speech_config, audio_config=audio_input, language=language)
+        if language != None:
+            # we know which language
+            logger.info(f'configuration speech recognition for language {language}')
+            speech_recognizer = azure.cognitiveservices.speech.SpeechRecognizer(speech_config=speech_config, audio_config=audio_input, language=language)
+        else:
+            # language unknown
+            logger.info(f'configuration speech recognition for any language')
+            speech_recognizer = azure.cognitiveservices.speech.SpeechRecognizer(speech_config=speech_config, audio_config=audio_input)
 
         # Starts speech recognition, and returns after a single utterance is recognized. The end of a
         # single utterance is determined by listening for silence at the end or until a maximum of 15
