@@ -1,4 +1,5 @@
 import enum
+from strenum import StrEnum
 
 class Language(enum.Enum):
     af = ("Afrikaans")
@@ -20,10 +21,12 @@ class Language(enum.Enum):
     bn = ("Bangla")
     bs = ("Bosnian")
     bg = ("Bulgarian")
+    brx = ("Bodo")
     ca = ("Catalan")
     ceb = ("Cebuano")
     ckb = ("Kurdish (Sorani)")
     doi = ("Dogri")
+    dsb = ("Lower Sorbian")
     ny = ("Chichewa")
     co = ("Corsican")
     hr = ("Croatian")
@@ -75,6 +78,7 @@ class Language(enum.Enum):
     lus = ("Mizo")
     rw = ("Kinyarwanda")
     ko = ("Korean")
+    ks = ("Kashmiri")
     ku = ("Kurdish (Central)")
     ky = ("Kyrgyz")
     lo = ("Lao")
@@ -169,6 +173,59 @@ class Language(enum.Enum):
     zh_lit = ("Chinese (Literary)")
 
 
+    def __init__(self, lang_name):
+        self.lang_name = lang_name        
+
+# maintain a smaller subset of commonly used languages
+# for chatbot purposes, trimming to the common list of languages saves tokens
+class CommonLanguage(enum.Enum):
+    af = ("Afrikaans")
+    ar = ("Arabic")
+    eu = ("Basque")
+    bg = ("Bulgarian")
+    ca = ("Catalan")
+    hr = ("Croatian")
+    cs = ("Czech")
+    da = ("Danish")
+    nl = ("Dutch")
+    en = ("English")
+    eo = ("Esperanto")
+    et = ("Estonian")
+    tl = ("Filipino")
+    fi = ("Finnish")
+    fr = ("French")
+    de = ("German")
+    el = ("Greek")
+    iw = ("Hebrew")
+    hi = ("Hindi")
+    hu = ("Hungarian")
+    is_ = ("Icelandic")
+    id_ = ("Indonesian")
+    ga = ("Irish")
+    it = ("Italian")
+    ja = ("Japanese")
+    ko = ("Korean")
+    lt = ("Lithuanian")
+    ne = ("Nepali")
+    no = ("Norwegian")
+    pl = ("Polish")
+    ro = ("Romanian")
+    ru = ("Russian")
+    sk = ("Slovak")
+    sl = ("Slovenian")
+    es = ("Spanish")
+    sv = ("Swedish")
+    th = ("Thai")
+    tr = ("Turkish")
+    uk = ("Ukrainian")
+    vi = ("Vietnamese")
+    cy = ("Welsh")
+    he = ("Hebrew")
+    fil = ("Filipino")
+    pt_pt = ("Portuguese")
+    yue = ("Cantonese")
+    zh_cn = ("Chinese")
+
     def __init__(self, lang_name):
         self.lang_name = lang_name        
 
@@ -358,7 +415,8 @@ AudioLanguageDefaults = {
     Language.sw: AudioLanguage.sw_TZ,
     Language.ta: AudioLanguage.ta_IN,
     Language.ur: AudioLanguage.ur_PK,
-    Language.zh_cn: AudioLanguage.zh_CN
+    Language.zh_cn: AudioLanguage.zh_CN,
+    Language.yue: AudioLanguage.zh_HK,
 }
 
 # if only one locale is available, make that the default
