@@ -126,7 +126,7 @@ class VoicenService(cloudlanguagetools.service.Service):
             return output_temp_file            
 
         # otherwise, an error occured
-        error_message = f"Status code: {response.status_code} reason: {response.reason} voice: [{voice_name}]]"
+        error_message = f"Could not retrieve audio from Voicen: status code: {response.status_code} reason: {response.reason}]]"
         raise cloudlanguagetools.errors.RequestError(error_message)
 
 
